# This example illustrates how SDMX codelists held and maintained in an FMR instance can be used as part of a data validation process in R
# The dataset does not need to be in an SDMX format


# install the rsdmx and validate packages
install.packages("rsdmx")
install.packages("validate")

# load the rsdmx and validate libraries
library(rsdmx)
library(validate)

# read the CSV dataset from a file into a data frame - this example assumes the file is at /tmp/activity_dataset.csv
activity <- read.csv("/tmp/activity_dataset.csv")

# create two validation rules using the validator() function from the 'validate' library
# Rule 1 - checks that obs_value > 0
# Rule 2 - pulls the ESTAT:CL_ACTIVITY codelist from FMR and checks that values for the 'activity' variable exist in that codelist
# We assume that the FMR's REST API endpoint is http://localhost:8080/ws/public/sdmxapi/rest
rules <- validator(obs_value > 0, activity %in% sdmx_codelist(endpoint = "http://localhost:8080/ws/public/sdmxapi/rest", agency_id = "ESTAT", resource_id = "CL_ACTIVITY"))

# execute the validation applying the 'rules' to the 'activity' data frame
out <- confront(activity,rules)

# print a summary of the validation results
summary(out)

# list those rows from the dataframe that violate one or more of the validation rules
violating(activity,rules)